==> webframe-0.9.1-src.zip: src/main/java/jp/sourceforge/webframe/compass/entity/TracTicketBean.java <==
/* vim: set tabstop=4 shiftwidth=4 softtabstop=4: */
/*
 * Copyright 2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.sourceforge.webframe.compass.entity;

/**
 * TracTicketBean
 *
 * @author Yomei Komiya
 * @since 0.9.0
 *
 * @version $Id$
 */
abstract public class TracTicketBean extends SearchableGenericEntity {

	private String status;
	
	private String owner;
	
	private String component;
	
	private String keywords;
	
	
	public void buildIdentifier() {
		// http://hostname/context/ticket/<id>
		this.setIdentifier(
				this.getResourceContext() + this.getLocalIdentifier());
	}


	public String getComponent() {
		return component;
	}


	public void setComponent(String component) {
		this.component = component;
	}


	public String getKeywords() {
		return keywords;
	}


	public void setKeywords(String keywords) {
		this.keywords = keywords;
	}


	public String getOwner() {
		return owner;
	}


	public void setOwner(String owner) {
		this.owner = owner;
	}


	public String getStatus() {
		return status;
	}


	public void setStatus(String status) {
		this.status = status;
	}
	
}

==> webframe-0.9.2-src.zip: src/main/java/jp/sourceforge/webframe/compass/entity/TracTicketBean.java <==
/* vim: set tabstop=4 shiftwidth=4 softtabstop=4: */
/*
 * Copyright 2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.sourceforge.webframe.compass.entity;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * TracTicketBean
 *
 * @author Yomei Komiya
 * @since 0.9.0
 *
 * @deprecated Use jp.sourceforge.metasearch.compass.entity.TracTicketBean
 *		of <a href="http://metasearch.sourceforge.jp/">MetaSearch project</a>
 * @version $Id$
 */
abstract public class TracTicketBean extends SearchableGenericEntity {

	private String status;
	
	private String owner;
	
	private String component;
	
	private String keywords;
	
	
	public void buildIdentifier() {
		// http://hostname/context/ticket/<id>
		this.setIdentifier(
				this.getResourceContext() + this.getLocalIdentifier());
	}


	public String getComponent() {
		return component;
	}


	public void setComponent(String component) {
		this.component = component;
	}


	public String getKeywords() {
		return keywords;
	}


	public void setKeywords(String keywords) {
		this.keywords = keywords;
	}


	public String getOwner() {
		return owner;
	}


	public void setOwner(String owner) {
		this.owner = owner;
	}


	public String getStatus() {
		return status;
	}


	public void setStatus(String status) {
		this.status = status;
	}


	public String toString() {
		String str = new ToStringBuilder(this)
			.append("status", status)
			.append("owner", owner)
			.append("component", component)
			.append("keywords", keywords)
			.toString();
		str += " < " + super.toString();

		return str;
	}
	
}
